@@ -4,7 +4,7 @@ use warnings;
 use Kwiki::Plugin '-Base';
 use Kwiki::Installer '-base';
 
-our $VERSION = 0.02;
+our $VERSION = 0.03_1;
 
 const class_title => 'color hiliting using Vim';
 const class_id => 'vim_mode';
@@ -21,14 +21,14 @@ use base 'Spoon::Formatter::WaflBlock';
 sub to_html {
     require Text::VimColor;
     my $string = $self->block_text;
-    $string =~ s/^ filetype: \s* (\w+) \s* \n+//smx;
     chomp $string;
+    $string =~ s/^ filetype: \s* (\w+) \s* \n+//smx;
+    my @filetype = $1 ? ( filetype => $1 ) : ();
     my $vim = Text::VimColor->new(
-        string => $string,
-        ( $1 ? ( filetype => $1 ) : () ),
-        vim_options => [ qw( -RXZ -i NONE -u NONE -N ), "+set nomodeline" ],
+        string=>$string, @filetype,
+        vim_options=>[qw( -RXZ -i NONE -u NONE -N ),"+set nomodeline"]
     );
-    return '<pre class="vim">' . $vim->html . '</pre>';
+    return '<pre class="vim">'.$vim->html."</pre>\n";
 }
 
 package Kwiki::VimMode;
@@ -38,13 +38,14 @@ __DATA__
 
 =head1 NAME 
 
-Kwiki::VimMode - syntax highlight preformatted forms of text
+Kwiki::VimMode - VimMode preformatted forms of text
 
 =head1 SYNOPSIS
 
  $ cpan Kwiki::VimMode
  $ cd /path/to/kwiki
- $ kwiki -add Kwiki::VimMode
+ $ echo "Kwiki::VimMode" >> plugins
+ $ kwiki -update
 
 =head1 DESCRIPTION
 
@@ -82,10 +83,6 @@ L<Text::VimColor>/Vim should hopefully pick up the correct syntax automatically.
     </VirtualHost>
     .vim
 
-=head1 NOTES
-
-Modelines are explicitly ignored.
-
 =head1 AUTHORS
 
 Ian Langworth <langworth.com>
